@@ -1,7 +1,6 @@
 module Top {
     module A__2 {
-        export function b__3() {
-        }
+        export function b__3() {}
     }
     A__2.b();
 }
